@@ -35,9 +35,9 @@
 #include <QMenuBar>
 #include <KLocalizedString>
 #include "ksirk_debug.h"
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KMessageBox>
+#include <KConfig>
+#include <KConfigGroup>
 
 namespace Ksirk
 {
