@@ -29,7 +29,7 @@
 
 #include "ksirk_debug.h"
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <KStringHandler>
 
 namespace Ksirk
